pub struct MechError {
pub program_range: Option<SourceRange>,
pub annotations: Vec<SourceRange>,
pub tokens: Vec<Token>,
pub compiler_location: Option<CompilerSourceRange>,
pub source: Option<Box<MechError>>,
pub message: Option<String>,
/* private fields */
}Fields
program_range: Option<SourceRange>annotations: Vec<SourceRange>tokens: Vec<Token>compiler_location: Option<CompilerSourceRange>source: Option<Box<MechError>>message: Option<String>Implementations
Sourceimpl MechError
impl MechError
pub fn new<K>(kind: K, message: Option<String>) -> MechErrorwhere
K: MechErrorKind2 + 'static,
Sourcepub fn kind_as<K>(&self) -> Option<&K>where
K: MechErrorKind2 + 'static,
pub fn kind_as<K>(&self) -> Option<&K>where
K: MechErrorKind2 + 'static,
Get the kind as a specific type, if it matches
Sourcepub fn kind_message(&self) -> String
pub fn kind_message(&self) -> String
Get the runtime message (delegates to the underlying kind)
Sourcepub fn display_message(&self) -> String
pub fn display_message(&self) -> String
Optional helper that returns the message or the explicit message override
Sourcepub fn kind_downcast_ref<K>(&self) -> Option<&K>where
K: 'static,
pub fn kind_downcast_ref<K>(&self) -> Option<&K>where
K: 'static,
If you ever need downcast access to the concrete kind:
Sourcepub fn with_compiler_loc(self) -> MechError
pub fn with_compiler_loc(self) -> MechError
Add a compiler location annotation with the current location
Sourcepub fn with_specific_compiler_loc(self, loc: CompilerSourceRange) -> MechError
pub fn with_specific_compiler_loc(self, loc: CompilerSourceRange) -> MechError
Specify a particular compiler location
Sourcepub fn with_annotation(self, range: SourceRange) -> MechError
pub fn with_annotation(self, range: SourceRange) -> MechError
Add a source range annotation
Sourcepub fn with_annotations<I>(self, iter: I) -> MechErrorwhere
I: IntoIterator<Item = SourceRange>,
pub fn with_annotations<I>(self, iter: I) -> MechErrorwhere
I: IntoIterator<Item = SourceRange>,
Add multiple source range annotations
Sourcepub fn with_tokens<I>(self, iter: I) -> MechErrorwhere
I: IntoIterator<Item = Token>,
pub fn with_tokens<I>(self, iter: I) -> MechErrorwhere
I: IntoIterator<Item = Token>,
Add tokens related to this error
Sourcepub fn with_source(self, src: MechError) -> MechError
pub fn with_source(self, src: MechError) -> MechError
Set the source error that caused this one
Sourcepub fn primary_range(&self) -> Option<SourceRange>
pub fn primary_range(&self) -> Option<SourceRange>
Get the primary source range associated with this error
Sourcepub fn simple_message(&self) -> String
pub fn simple_message(&self) -> String
Get a simple message describing the error
Sourcepub fn full_chain_message(&self) -> String
pub fn full_chain_message(&self) -> String
Get a full chain message including all source errors
pub fn boxed(self) -> Box<MechError>